@@ -19,13 +19,16 @@ class aubio_cmd(TestCase):
 class aubio_cmd_utils(TestCase):
 
     def test_samples2seconds(self):
-        self.assertEqual(aubio.cmd.samples2seconds(3200, 32000), "0.100000\t")
+        self.assertEqual(aubio.cmd.samples2seconds(3200, 32000),
+                "0.100000\t")
 
     def test_samples2milliseconds(self):
-        self.assertEqual(aubio.cmd.samples2milliseconds(3200, 32000), "100.000000\t")
+        self.assertEqual(aubio.cmd.samples2milliseconds(3200, 32000),
+                "100.000000\t")
 
     def test_samples2samples(self):
-        self.assertEqual(aubio.cmd.samples2samples(3200, 32000), "3200\t")
+        self.assertEqual(aubio.cmd.samples2samples(3200, 32000),
+                "3200\t")
 
 if __name__ == '__main__':
     main()
