@@ -28,8 +28,13 @@
 #include "spectral/fft.h"
 #include "spectral/filterbank.h"
 #include "spectral/filterbank_mel.h"
+#include "spectral/dct.h"
 #include "spectral/mfcc.h"
 
+#ifdef HAVE_NOOPT
+#define HAVE_SLOW_DCT 1
+#endif
+
 /** Internal structure for mfcc object */
 
 struct _aubio_mfcc_t
@@ -40,7 +45,13 @@ struct _aubio_mfcc_t
   uint_t n_coefs;           /** number of coefficients (<= n_filters/2 +1) */
   aubio_filterbank_t *fb;   /** filter bank */
   fvec_t *in_dct;           /** input buffer for dct * [fb->n_filters] */
+#if defined(HAVE_SLOW_DCT)
   fmat_t *dct_coeffs;       /** DCT transform n_filters * n_coeffs */
+#else
+  aubio_dct_t *dct;
+  fvec_t *output;
+#endif
+  smpl_t scale;
 };
 
 
@@ -51,9 +62,11 @@ new_aubio_mfcc (uint_t win_s, uint_t n_filters, uint_t n_coefs,
 
   /* allocate space for mfcc object */
   aubio_mfcc_t *mfcc = AUBIO_NEW (aubio_mfcc_t);
+#if defined(HAVE_SLOW_DCT)
   smpl_t scaling;
 
   uint_t i, j;
+#endif
 
   mfcc->win_s = win_s;
   mfcc->samplerate = samplerate;
@@ -62,11 +75,16 @@ new_aubio_mfcc (uint_t win_s, uint_t n_filters, uint_t n_coefs,
 
   /* filterbank allocation */
   mfcc->fb = new_aubio_filterbank (n_filters, mfcc->win_s);
-  aubio_filterbank_set_mel_coeffs_slaney (mfcc->fb, samplerate);
+  if (n_filters == 40)
+    aubio_filterbank_set_mel_coeffs_slaney (mfcc->fb, samplerate);
+  else
+    aubio_filterbank_set_mel_coeffs(mfcc->fb, samplerate,
+        0, samplerate/2.);
 
   /* allocating buffers */
   mfcc->in_dct = new_fvec (n_filters);
 
+#if defined(HAVE_SLOW_DCT)
   mfcc->dct_coeffs = new_fmat (n_coefs, n_filters);
 
   /* compute DCT transform dct_coeffs[j][i] as
@@ -79,6 +97,12 @@ new_aubio_mfcc (uint_t win_s, uint_t n_filters, uint_t n_coefs,
     }
     mfcc->dct_coeffs->data[0][i] *= SQRT (2.) / 2.;
   }
+#else
+  mfcc->dct = new_aubio_dct (n_filters);
+  mfcc->output = new_fvec (n_filters);
+#endif
+
+  mfcc->scale = 1.;
 
   return mfcc;
 }
@@ -92,7 +116,12 @@ del_aubio_mfcc (aubio_mfcc_t * mf)
 
   /* delete buffers */
   del_fvec (mf->in_dct);
+#if defined(HAVE_SLOW_DCT)
   del_fmat (mf->dct_coeffs);
+#else
+  del_aubio_dct (mf->dct);
+  del_fvec (mf->output);
+#endif
 
   /* delete mfcc object */
   AUBIO_FREE (mf);
@@ -102,17 +131,69 @@ del_aubio_mfcc (aubio_mfcc_t * mf)
 void
 aubio_mfcc_do (aubio_mfcc_t * mf, const cvec_t * in, fvec_t * out)
 {
+#ifndef HAVE_SLOW_DCT
+  fvec_t tmp;
+#endif
+
   /* compute filterbank */
   aubio_filterbank_do (mf->fb, in, mf->in_dct);
 
   /* compute log10 */
   fvec_log10 (mf->in_dct);
 
-  /* raise power */
-  //fvec_pow (mf->in_dct, 3.);
+  if (mf->scale != 1) fvec_mul (mf->in_dct, mf->scale);
 
   /* compute mfccs */
+#if defined(HAVE_SLOW_DCT)
   fmat_vecmul(mf->dct_coeffs, mf->in_dct, out);
+#else
+  aubio_dct_do(mf->dct, mf->in_dct, mf->output);
+  // copy only first n_coeffs elements
+  // TODO assert mf->output->length == n_coeffs
+  tmp.data = mf->output->data;
+  tmp.length = out->length;
+  fvec_copy(&tmp, out);
+#endif
 
   return;
 }
+
+uint_t aubio_mfcc_set_power (aubio_mfcc_t *mf, smpl_t power)
+{
+  return aubio_filterbank_set_power(mf->fb, power);
+}
+
+uint_t aubio_mfcc_get_power (aubio_mfcc_t *mf)
+{
+  return aubio_filterbank_get_power(mf->fb);
+}
+
+uint_t aubio_mfcc_set_scale (aubio_mfcc_t *mf, smpl_t scale)
+{
+  mf->scale = scale;
+  return AUBIO_OK;
+}
+
+uint_t aubio_mfcc_get_scale (aubio_mfcc_t *mf)
+{
+  return mf->scale;
+}
+
+uint_t aubio_mfcc_set_mel_coeffs (aubio_mfcc_t *mf, smpl_t freq_min,
+    smpl_t freq_max)
+{
+  return aubio_filterbank_set_mel_coeffs(mf->fb, mf->samplerate,
+      freq_min, freq_max);
+}
+
+uint_t aubio_mfcc_set_mel_coeffs_htk (aubio_mfcc_t *mf, smpl_t freq_min,
+    smpl_t freq_max)
+{
+  return aubio_filterbank_set_mel_coeffs_htk(mf->fb, mf->samplerate,
+      freq_min, freq_max);
+}
+
+uint_t aubio_mfcc_set_mel_coeffs_slaney (aubio_mfcc_t *mf)
+{
+  return aubio_filterbank_set_mel_coeffs_slaney (mf->fb, mf->samplerate);
+}
