@@ -8,6 +8,19 @@ int main (void)
   fvec_t *out = new_fvec (win_s); // input buffer
 
   aubio_filter_t *o = new_aubio_filter_c_weighting (44100);
+
+  if (new_aubio_filter(0))
+    return 1;
+
+  if (aubio_filter_get_samplerate(o) != 44100)
+    return 1;
+
+  if (aubio_filter_set_c_weighting (o, -1) == 0)
+    return 1;
+
+  if (aubio_filter_set_c_weighting (0, 32000) == 0)
+    return 1;
+
   in->data[impulse_at] = 0.5;
   fvec_print (in);
   aubio_filter_do (o, in);
@@ -15,6 +28,12 @@ int main (void)
   del_aubio_filter (o);
 
   o = new_aubio_filter_a_weighting (32000);
+
+  if (aubio_filter_set_a_weighting (o, -1) == 0)
+    return 1;
+  if (aubio_filter_set_a_weighting (0, 32000) == 0)
+    return 1;
+
   in->data[impulse_at] = 0.5;
   fvec_print (in);
   aubio_filter_do_outplace (o, in, out);
